@@ -70,7 +70,7 @@ struct GSWindowPrivate
         guint64    logout_timeout;
         char      *logout_command;
         char      *keyboard_command;
-        char      *away_message;
+        char      *status_message;
 
         GtkWidget *vbox;
         GtkWidget *drawing_area;
@@ -125,7 +125,7 @@ enum {
         PROP_LOGOUT_COMMAND,
         PROP_LOGOUT_TIMEOUT,
         PROP_MONITOR,
-        PROP_AWAY_MESSAGE
+        PROP_STATUS_MESSAGE
 };
 
 static guint           signals [LAST_SIGNAL] = { 0, };
@@ -414,6 +414,12 @@ update_geometry (GSWindow *window)
         gdk_screen_get_monitor_geometry (GTK_WINDOW (window)->screen,
                                          window->priv->monitor,
                                          &geometry);
+        gs_debug ("got geometry for monitor %d: x=%d y=%d w=%d h=%d",
+                  window->priv->monitor,
+                  geometry.x,
+                  geometry.y,
+                  geometry.width,
+                  geometry.height);
         monitor_region = gdk_region_rectangle (&geometry);
         gdk_region_subtract (monitor_region, outside_region);
         gdk_region_destroy (outside_region);
@@ -421,6 +427,13 @@ update_geometry (GSWindow *window)
         gdk_region_get_clipbox (monitor_region, &geometry);
         gdk_region_destroy (monitor_region);
 
+        gs_debug ("using geometry for monitor %d: x=%d y=%d w=%d h=%d",
+                  window->priv->monitor,
+                  geometry.x,
+                  geometry.y,
+                  geometry.width,
+                  geometry.height);
+
         window->priv->geometry.x = geometry.x;
         window->priv->geometry.y = geometry.y;
         window->priv->geometry.width = geometry.width;
@@ -957,6 +970,7 @@ error_watch (GIOChannel   *source,
                 case G_IO_STATUS_ERROR:
                         finished = TRUE;
                         gs_debug ("Error reading from child: %s\n", error->message);
+                        g_error_free (error);
                         return FALSE;
                 case G_IO_STATUS_AGAIN:
                 default:
@@ -1269,6 +1283,7 @@ keyboard_command_watch (GIOChannel   *source,
                 case G_IO_STATUS_ERROR:
                         finished = TRUE;
                         gs_debug ("Error reading from child: %s\n", error->message);
+                        g_error_free (error);
                         return FALSE;
                 case G_IO_STATUS_AGAIN:
                 default:
@@ -1450,6 +1465,7 @@ lock_command_watch (GIOChannel   *source,
                 case G_IO_STATUS_ERROR:
                         finished = TRUE;
                         gs_debug ("Error reading from child: %s\n", error->message);
+                        g_error_free (error);
                         return FALSE;
                 case G_IO_STATUS_AGAIN:
                 default:
@@ -1532,11 +1548,11 @@ popup_dialog_idle (GSWindow *window)
                 g_string_append_printf (command, " --logout-command='%s'", window->priv->logout_command);
         }
 
-        if (window->priv->away_message) {
+        if (window->priv->status_message) {
                 char *quoted;
 
-                quoted = g_shell_quote (window->priv->away_message);
-                g_string_append_printf (command, " --away-message=%s", quoted);
+                quoted = g_shell_quote (window->priv->status_message);
+                g_string_append_printf (command, " --status-message=%s", quoted);
                 g_free (quoted);
         }
 
@@ -1722,13 +1738,13 @@ gs_window_set_logout_command (GSWindow   *window,
 }
 
 void
-gs_window_set_away_message (GSWindow   *window,
-                            const char *away_message)
+gs_window_set_status_message (GSWindow   *window,
+                            const char *status_message)
 {
         g_return_if_fail (GS_IS_WINDOW (window));
 
-        g_free (window->priv->away_message);
-        window->priv->away_message = g_strdup (away_message);
+        g_free (window->priv->status_message);
+        window->priv->status_message = g_strdup (status_message);
 }
 
 void
@@ -1782,8 +1798,8 @@ gs_window_set_property (GObject            *object,
         case PROP_LOGOUT_COMMAND:
                 gs_window_set_logout_command (self, g_value_get_string (value));
                 break;
-        case PROP_AWAY_MESSAGE:
-                gs_window_set_away_message (self, g_value_get_string (value));
+        case PROP_STATUS_MESSAGE:
+                gs_window_set_status_message (self, g_value_get_string (value));
                 break;
         case PROP_LOGOUT_TIMEOUT:
                 gs_window_set_logout_timeout (self, g_value_get_long (value));
@@ -1823,8 +1839,8 @@ gs_window_get_property (GObject    *object,
         case PROP_LOGOUT_COMMAND:
                 g_value_set_string (value, self->priv->logout_command);
                 break;
-        case PROP_AWAY_MESSAGE:
-                g_value_set_string (value, self->priv->away_message);
+        case PROP_STATUS_MESSAGE:
+                g_value_set_string (value, self->priv->status_message);
                 break;
         case PROP_LOGOUT_TIMEOUT:
                 g_value_set_long (value, self->priv->logout_timeout);
@@ -2168,8 +2184,8 @@ gs_window_class_init (GSWindowClass *klass)
                                                               NULL,
                                                               G_PARAM_READWRITE));
         g_object_class_install_property (object_class,
-                                         PROP_AWAY_MESSAGE,
-                                         g_param_spec_string ("away-message",
+                                         PROP_STATUS_MESSAGE,
+                                         g_param_spec_string ("status-message",
                                                               NULL,
                                                               NULL,
                                                               NULL,
